@@ -1,7 +1,7 @@
-from wedoc.api.client import WedocClient
+from wedoc.api.client import WedocClientBase
 
 
-class Document(WedocClient):
+class Document(WedocClientBase):
     def __init__(self) -> None:
         pass
 
