@@ -1,4 +1,6 @@
-class Spreadsheet:
+from wedoc.api.client import WedocClientBase
+
+class Spreadsheet(WedocClientBase):
     def __init__(self) -> None:
         pass
 
